@@ -62,10 +62,11 @@ def prepare_benchmark_definitions(args):
     ) = get_defaults(defaults_filename)
     for usecase_filename in files:
         with open(usecase_filename, "r") as stream:
-            benchmark_config, test_name = get_final_benchmark_config(
+            result, benchmark_config, test_name = get_final_benchmark_config(
                 default_kpis, stream, usecase_filename
             )
-            benchmark_definitions[test_name] = benchmark_config
+            if result:
+                benchmark_definitions[test_name] = benchmark_config
     return (
         benchmark_definitions,
         default_metrics,
@@ -109,15 +110,28 @@ def get_defaults(defaults_filename):
 
 
 def get_final_benchmark_config(default_kpis, stream, usecase_filename):
-    os.path.dirname(os.path.abspath(usecase_filename))
-    benchmark_config = yaml.safe_load(stream)
-    kpis_keyname = "kpis"
-    if default_kpis is not None:
-        merge_default_and_specific_properties_dict_type(
-            benchmark_config, default_kpis, kpis_keyname, usecase_filename
+    result = False
+    benchmark_config = None
+    test_name = None
+    try:
+        os.path.dirname(os.path.abspath(usecase_filename))
+        benchmark_config = yaml.safe_load(stream)
+        kpis_keyname = "kpis"
+        if default_kpis is not None:
+            merge_default_and_specific_properties_dict_type(
+                benchmark_config, default_kpis, kpis_keyname, usecase_filename
+            )
+        test_name = benchmark_config["name"]
+        result = True
+    except Exception as e:
+        logging.error(
+            "while loading file {} and error was returned: {}".format(
+                usecase_filename, e.__str__()
+            )
         )
-    test_name = benchmark_config["name"]
-    return benchmark_config, test_name
+        pass
+
+    return result, benchmark_config, test_name
 
 
 def merge_default_and_specific_properties_dict_type(
@@ -173,27 +187,47 @@ def merge_default_and_specific_properties_dict_type(
 
 def extract_redis_dbconfig_parameters(benchmark_config, dbconfig_keyname):
     redis_configuration_parameters = {}
+    modules_configuration_parameters_map = {}
     dataset_load_timeout_secs = 120
     dataset_name = None
     dbconfig_present = False
     if dbconfig_keyname in benchmark_config:
         dbconfig_present = True
-        for k in benchmark_config[dbconfig_keyname]:
-            if "configuration-parameters" in k:
-                cp = k["configuration-parameters"]
-                for item in cp:
-                    for k, v in item.items():
-                        redis_configuration_parameters[k] = v
-            if "dataset_load_timeout_secs" in k:
-                dataset_load_timeout_secs = k["dataset_load_timeout_secs"]
-            if "dataset_name" in k:
-                dataset_name = k["dataset_name"]
+        if type(benchmark_config[dbconfig_keyname]) == list:
+            for k in benchmark_config[dbconfig_keyname]:
+                if "module-configuration-parameters" in k:
+                    modules_configuration_parameters_map = k[
+                        "module-configuration-parameters"
+                    ]
+                if "configuration-parameters" in k:
+                    cp = k["configuration-parameters"]
+                    for item in cp:
+                        for k, v in item.items():
+                            redis_configuration_parameters[k] = v
+                if "dataset_load_timeout_secs" in k:
+                    dataset_load_timeout_secs = k["dataset_load_timeout_secs"]
+                if "dataset_name" in k:
+                    dataset_name = k["dataset_name"]
+        if type(benchmark_config[dbconfig_keyname]) == dict:
+            if "module-configuration-parameters" in benchmark_config[dbconfig_keyname]:
+                modules_configuration_parameters_map = benchmark_config[
+                    dbconfig_keyname
+                ]["module-configuration-parameters"]
+            if "configuration-parameters" in benchmark_config[dbconfig_keyname]:
+                cp = benchmark_config[dbconfig_keyname]["configuration-parameters"]
+                for k, v in cp.items():
+                    redis_configuration_parameters[k] = v
+                if "dataset_load_timeout_secs" in cp:
+                    dataset_load_timeout_secs = cp["dataset_load_timeout_secs"]
+                if "dataset_name" in cp:
+                    dataset_name = cp["dataset_name"]
 
     return (
         dbconfig_present,
         dataset_name,
         redis_configuration_parameters,
         dataset_load_timeout_secs,
+        modules_configuration_parameters_map,
     )
 
 
